Modules
=======

.. toctree::
   :maxdepth: 4

   reclist


Abstractions
------------


.. automodule:: reclist.abstractions
    :members:
    :undoc-members:
    :show-inheritance:

Datasets
--------

Data sets currently available

.. automodule:: reclist.datasets
    :members:
    :undoc-members:
    :show-inheritance:

Metrics
--------

Metrics

.. automodule:: reclist.metrics
    :members:
    :undoc-members:
    :show-inheritance:
